@@ -15,9 +15,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-require File::join(File::dirname(__FILE__), 'test_helper')
+require 'minitest/autorun'
+require 'hivex'
 
-class TestLoad < MiniTest::Unit::TestCase
+class TestLoad < Minitest::Test
   def test_load
     h = Hivex::open("../images/minimal", {})
     refute_nil (h)
