@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 # -*- ruby -*-
 
-require File::join(File::dirname(__FILE__), 'test_helper')
+require 'minitest/autorun'
+require 'hivex'
 
-class TestRLenValue < MiniTest::Unit::TestCase
+class TestRLenValue < Minitest::Test
   def test_RLenValue
     h = Hivex::open(File::join(ENV['abs_srcdir'], '..', 'images', 'special'), {})
     refute_nil(h)
@@ -13,17 +14,17 @@ class TestRLenValue < MiniTest::Unit::TestCase
 
     nodes = h.node_children (root)
     node = nodes.find { |n| h.node_name(n) == "abcd_äöüß" }
-    assert node != nil
+    refute_nil(node)
     value = h.node_values(node).find { |v| h.value_key(v) == "abcd_äöüß" }
-    assert value != nil
+    refute_nil(value)
     node = nodes.find { |n| h.node_name(n) == "zero\0key" }
-    assert node != nil
+    refute_nil(node)
     value = h.node_values(node).find { |v| h.value_key(v) == "zero\0val" }
-    assert value != nil
+    refute_nil(value)
     node = nodes.find { |n| h.node_name(n) == "weird™" }
-    assert node != nil
+    refute_nil(node)
     value = h.node_values(node).find { |v| h.value_key(v) == "symbols $£₤₧€" }
-    assert value != nil
+    refute_nil(value)
 
   end
 end
