@@ -15,9 +15,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-require File::join(File::dirname(__FILE__), 'test_helper')
+require 'minitest/autorun'
+require 'hivex'
 
-class TestWrite < MiniTest::Unit::TestCase
+class TestWrite < Minitest::Test
   def test_write
     h = Hivex::open("../images/minimal", {:write => 1})
     refute_nil (h)
